@@ -22,3 +22,13 @@ class BaseSchema:
     hint = marshmallow.fields.String(
         required=False
     )
+
+    backoff = marshmallow.fields.Dict(
+        required=False
+    )
+
+    def dump(self, *args, **kwargs) -> dict:
+        return {
+            k: v for k, v in dict.items(super().dump(*args, **kwargs))
+            if v is not None
+        }
